from .generic import ContactView, LoginView, LogoutView
from .media import (
    MediaCreateView,
    MediaDeleteView,
    MediaDetailView,
    MediaGalleryView,
    MediaSearchView,
    MediaUpdateView,
    MediaUploadView,
    MediaUploadSuccessView,
    MediaSearchResultsView,
)
from .tags import (
    TagCreateView,
    TagDeleteView,
    TagUpdateView,
)
